{-# LANGUAGE PackageImports #-}

import D
import "a" Ab
import "b" Aa
import "b" Bb
import "c" Ba
import "zzzz" Z
import "this" Y
